@@ -7,14 +7,14 @@
 /*	#include "bounce_service.h"
 /*
 /*	int     bounce_notify_service(flags, service, queue_name, queue_id,
-/*					encoding, smtputf8, sender, dsn_envid,
+/*					encoding, sendopts, sender, dsn_envid,
 /*					dsn_ret, templates)
 /*	int	flags;
 /*	char	*service;
 /*	char	*queue_name;
 /*	char	*queue_id;
 /*	char	*encoding;
-/*	int	smtputf8;
+/*	int	sendopts;
 /*	char	*sender;
 /*	char	*dsn_envid;
 /*	int	dsn_ret;
@@ -84,7 +84,7 @@
 
 int     bounce_notify_service(int flags, char *service, char *queue_name,
 			              char *queue_id, char *encoding,
-			              int smtputf8, char *recipient,
+			              int sendopts, char *recipient,
 			              char *dsn_envid, int dsn_ret,
 			              BOUNCE_TEMPLATES *ts)
 {
@@ -131,7 +131,7 @@ int     bounce_notify_service(int flags, char *service, char *queue_name,
      * notification is enabled.
      */
     bounce_info = bounce_mail_init(service, queue_name, queue_id,
-				   encoding, smtputf8, dsn_envid,
+				   encoding, sendopts, dsn_envid,
 				   ts->failure);
 
 #define NULL_SENDER		MAIL_ADDR_EMPTY	/* special address */
@@ -179,7 +179,7 @@ int     bounce_notify_service(int flags, char *service, char *queue_name,
 						 postmaster,
 						 MAIL_SRC_MASK_BOUNCE,
 						 NULL_TRACE_FLAGS,
-						 smtputf8,
+						 sendopts,
 						 new_id)) != 0) {
 
 		/*
@@ -219,7 +219,7 @@ int     bounce_notify_service(int flags, char *service, char *queue_name,
 	if ((bounce = post_mail_fopen_nowait(NULL_SENDER, recipient,
 					     MAIL_SRC_MASK_BOUNCE,
 					     NULL_TRACE_FLAGS,
-					     smtputf8,
+					     sendopts,
 					     new_id)) != 0) {
 
 	    /*
@@ -274,7 +274,7 @@ int     bounce_notify_service(int flags, char *service, char *queue_name,
 						 postmaster,
 						 MAIL_SRC_MASK_BOUNCE,
 						 NULL_TRACE_FLAGS,
-						 smtputf8,
+						 sendopts,
 						 new_id)) != 0) {
 		count = -1;
 		if (bounce_header(bounce, bounce_info, postmaster,
