@@ -221,6 +221,7 @@ int     cleanup_bounce(CLEANUP_STATE *state)
 	    encoding = MAIL_ATTR_ENC_NONE;
 	dsn_envid = state->dsn_envid ?
 	    state->dsn_envid : "";
+	/* Do not send unfiltered (body) content. */
 	dsn_ret = (state->errs & (CLEANUP_STAT_CONT | CLEANUP_STAT_SIZE)) ?
 	    DSN_RET_HDRS : state->dsn_ret;
 
@@ -228,14 +229,14 @@ int     cleanup_bounce(CLEANUP_STATE *state)
 	    bounce_err =
 		bounce_flush(BOUNCE_FLAG_CLEAN,
 			     state->queue_name, state->queue_id,
-			     encoding, state->sender, dsn_envid,
-			     dsn_ret);
+			     encoding, state->sendopts, state->sender,
+			     dsn_envid, dsn_ret);
 	} else {
 	    bounce_err =
 		bounce_flush_verp(BOUNCE_FLAG_CLEAN,
 				  state->queue_name, state->queue_id,
-				  encoding, state->sender, dsn_envid,
-				  dsn_ret, state->verp_delims);
+				  encoding, state->sendopts, state->sender,
+				  dsn_envid, dsn_ret, state->verp_delims);
 	}
 	if (bounce_err != 0) {
 	    msg_warn("%s: bounce message failure", state->queue_id);
