@@ -71,6 +71,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -125,6 +130,7 @@ int     flush_purge(void)
 	status = FLUSH_STAT_DENY;
     else
 	status = mail_command_client(MAIL_CLASS_PUBLIC, var_flush_service,
+				     MAIL_ATTR_PROTO_FLUSH,
 			      SEND_ATTR_STR(MAIL_ATTR_REQ, FLUSH_REQ_PURGE),
 				     ATTR_TYPE_END);
 
@@ -151,6 +157,7 @@ int     flush_refresh(void)
 	status = FLUSH_STAT_DENY;
     else
 	status = mail_command_client(MAIL_CLASS_PUBLIC, var_flush_service,
+				     MAIL_ATTR_PROTO_FLUSH,
 			    SEND_ATTR_STR(MAIL_ATTR_REQ, FLUSH_REQ_REFRESH),
 				     ATTR_TYPE_END);
 
@@ -182,6 +189,7 @@ int     flush_send_site(const char *site)
 		     VAR_RELAY_DOMAINS "=$mydestination to flush "
 		     "mail for domain \"%s\"", site);
 	status = mail_command_client(MAIL_CLASS_PUBLIC, var_flush_service,
+				     MAIL_ATTR_PROTO_FLUSH,
 			  SEND_ATTR_STR(MAIL_ATTR_REQ, FLUSH_REQ_SEND_SITE),
 				     SEND_ATTR_STR(MAIL_ATTR_SITE, site),
 				     ATTR_TYPE_END);
@@ -210,6 +218,7 @@ int     flush_send_file(const char *queue_id)
      * Require that the service is turned on.
      */
     status = mail_command_client(MAIL_CLASS_PUBLIC, var_flush_service,
+				 MAIL_ATTR_PROTO_FLUSH,
 			  SEND_ATTR_STR(MAIL_ATTR_REQ, FLUSH_REQ_SEND_FILE),
 				 SEND_ATTR_STR(MAIL_ATTR_QUEUEID, queue_id),
 				 ATTR_TYPE_END);
@@ -242,6 +251,7 @@ int     flush_add(const char *site, const char *queue_id)
 		     VAR_RELAY_DOMAINS "=$mydestination to update "
 		     "fast-flush logfile for domain \"%s\"", site);
 	status = mail_command_client(MAIL_CLASS_PUBLIC, var_flush_service,
+				     MAIL_ATTR_PROTO_FLUSH,
 				SEND_ATTR_STR(MAIL_ATTR_REQ, FLUSH_REQ_ADD),
 				     SEND_ATTR_STR(MAIL_ATTR_SITE, site),
 				 SEND_ATTR_STR(MAIL_ATTR_QUEUEID, queue_id),
