@@ -82,6 +82,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -177,9 +182,21 @@ int     get_mail_conf_int_fn(const char *name, stupid_indent_int defval,
 
 void    set_mail_conf_int(const char *name, int value)
 {
+    const char myname[] = "set_mail_conf_int";
     char    buf[BUFSIZ];		/* yeah! crappy code! */
 
+#ifndef NO_SNPRINTF
+    ssize_t ret;
+
+    ret = snprintf(buf, sizeof(buf), "%d", value);
+    if (ret < 0)
+	msg_panic("%s: output error for %%d", myname);
+    if (ret >= sizeof(buf))
+	msg_panic("%s: output for %%d exceeds space %ld",
+		  myname, (long) sizeof(buf));
+#else
     sprintf(buf, "%d", value);			/* yeah! more crappy code! */
+#endif
     mail_conf_update(name, buf);
 }
 
