@@ -53,8 +53,8 @@
 /*	char	*format;
 /*	va_list	ap;
 /*
-/*	int	smtp_forbid_bare_lf;
-/*	int	smtp_detected_bare_lf;
+/*	int	smtp_detect_bare_lf;
+/*	int	smtp_got_bare_lf;
 /* AUXILIARY API
 /*	int	smtp_get_noexcept(vp, stream, maxlen, flags)
 /*	VSTRING	*vp;
@@ -136,15 +136,14 @@
 /*	smtp_get_noexcept() implements the subset of smtp_get()
 /*	without timeouts and without making long jumps. Instead,
 /*	query the stream status with vstream_feof() etc.
-/*	This function will set smtp_detected_bare_lf when flagging
-/*	input with a bare newline byte.
+/*
+/*	This function assigns smtp_got_bare_lf = smtp_detect_bare_lf,
+/*	if smtp_detect_bare_lf is non-zero and the last read line
+/*	was terminated with a bare newline. Otherwise, this function
+/*	sets smtp_got_bare_lf to zero.
 /*
 /*	smtp_timeout_setup() is a backwards-compatibility interface
 /*	for programs that don't require deadline or data-rate support.
-/*
-/*	smtp_forbid_bare_lf controls whether smtp_get_noexcept()
-/*	will set smtp_detected_bare_lf when the line that was read
-/*	last ended with a bare newline byte.
 /* DIAGNOSTICS
 /* .fi
 /* .ad
@@ -223,8 +222,8 @@
   * the buffer. Such system calls would really hurt when receiving or sending
   * body content one line at a time.
   */
-int     smtp_forbid_bare_lf;
-int     smtp_detected_bare_lf;
+int     smtp_detect_bare_lf;
+int     smtp_got_bare_lf;
 
 /* smtp_timeout_reset - reset per-stream error flags */
 
@@ -387,7 +386,7 @@ int     smtp_get_noexcept(VSTRING *vp, VSTREAM *stream, ssize_t bound, int flags
     int     last_char;
     int     next_char;
 
-    smtp_detected_bare_lf = 0;
+    smtp_got_bare_lf = 0;
 
     /*
      * It's painful to do I/O with records that may span multiple buffers.
@@ -431,9 +430,9 @@ int     smtp_get_noexcept(VSTRING *vp, VSTREAM *stream, ssize_t bound, int flags
 	 */
     case '\n':
 	vstring_truncate(vp, VSTRING_LEN(vp) - 1);
-	if (smtp_forbid_bare_lf) {
+	if (smtp_detect_bare_lf) {
 	    if (VSTRING_LEN(vp) == 0 || vstring_end(vp)[-1] != '\r')
-		smtp_detected_bare_lf = smtp_forbid_bare_lf;
+		smtp_got_bare_lf = smtp_detect_bare_lf;
 	    else
 		vstring_truncate(vp, VSTRING_LEN(vp) - 1);
 	} else {
