@@ -84,7 +84,7 @@ static void master_unthrottle(MASTER_SERV *serv);
 
 /* master_unthrottle_wrapper - in case (char *) != (struct *) */
 
-static void master_unthrottle_wrapper(int unused_event, char *ptr)
+static void master_unthrottle_wrapper(int unused_event, void *ptr)
 {
     MASTER_SERV *serv = (MASTER_SERV *) ptr;
 
@@ -107,7 +107,7 @@ static void master_unthrottle(MASTER_SERV *serv)
      */
     if ((serv->flags & MASTER_FLAG_THROTTLE) != 0) {
 	serv->flags &= ~MASTER_FLAG_THROTTLE;
-	event_cancel_timer(master_unthrottle_wrapper, (char *) serv);
+	event_cancel_timer(master_unthrottle_wrapper, (void *) serv);
 	if (msg_verbose)
 	    msg_info("throttle released for command %s", serv->path);
 	master_avail_listen(serv);
@@ -126,7 +126,7 @@ static void master_throttle(MASTER_SERV *serv)
      */
     if ((serv->flags & MASTER_FLAG_THROTTLE) == 0) {
 	serv->flags |= MASTER_FLAG_THROTTLE;
-	event_request_timer(master_unthrottle_wrapper, (char *) serv,
+	event_request_timer(master_unthrottle_wrapper, (void *) serv,
 			    serv->throttle_delay);
 	if (msg_verbose)
 	    msg_info("throttling command %s", serv->path);
@@ -247,8 +247,8 @@ void    master_spawn(MASTER_SERV *serv)
 	proc->gen = master_generation;
 	proc->use_count = 0;
 	proc->avail = 0;
-	binhash_enter(master_child_table, (char *) &pid,
-		      sizeof(pid), (char *) proc);
+	binhash_enter(master_child_table, (void *) &pid,
+		      sizeof(pid), (void *) proc);
 	serv->total_proc++;
 	master_avail_more(serv, proc);
 	if (serv->flags & MASTER_FLAG_CONDWAKE) {
@@ -278,9 +278,9 @@ static void master_delete_child(MASTER_PROC *proc)
 	master_avail_less(serv, proc);
     else
 	master_avail_listen(serv);
-    binhash_delete(master_child_table, (char *) &proc->pid,
-		   sizeof(proc->pid), (void (*) (char *)) 0);
-    myfree((char *) proc);
+    binhash_delete(master_child_table, (void *) &proc->pid,
+		   sizeof(proc->pid), (void (*) (void *)) 0);
+    myfree((void *) proc);
 }
 
 /* master_reap_child - reap dead children */
@@ -301,8 +301,11 @@ void    master_reap_child(void)
 	if (msg_verbose)
 	    msg_info("master_reap_child: pid %d", pid);
 	if ((proc = (MASTER_PROC *) binhash_find(master_child_table,
-					  (char *) &pid, sizeof(pid))) == 0)
+					(void *) &pid, sizeof(pid))) == 0) {
+	    if (init_mode)
+		continue;			/* non-Postfix process */
 	    msg_panic("master_reap: unknown pid: %d", pid);
+	}
 	serv = proc->serv;
 
 #define MASTER_KILL_SIGNAL	SIGTERM
@@ -363,6 +366,6 @@ void    master_delete_children(MASTER_SERV *serv)
     }
     while (serv->total_proc > 0)
 	master_reap_child();
-    myfree((char *) list);
+    myfree((void *) list);
     master_unthrottle(serv);
 }
