@@ -654,6 +654,13 @@
 /* .IP "\fBtls_required_enable (yes)\fR"
 /*	Enable support for the "TLS-Required: no" message header, defined
 /*	in RFC 8689.
+/* .PP
+/*	Available in Postfix version 3.10.5 and later:
+/* .IP "\fBsmtp_tls_enforce_sts_mx_patterns (yes)\fR"
+/*	Transform the TLS policy from an STS policy plugin: connect to
+/*	an MX host only if its name matches any STS policy MX host pattern,
+/*	and match the server certificate against the MX hostname.
+/* .PP
 /* OBSOLETE STARTTLS CONTROLS
 /* .ad
 /* .fi
@@ -1133,6 +1140,7 @@ bool    var_smtp_tls_blk_early_mail_reply;
 bool    var_smtp_tls_force_tlsa;
 char   *var_smtp_tls_insecure_mx_policy;
 bool    var_smtp_tls_enable_rpk;
+bool    var_smtp_tls_enf_sts_mx_pat;
 
 #endif
 
