@@ -18,9 +18,7 @@ extern int unix_trigger(const char *, const char *, ssize_t, int);
 extern int inet_trigger(const char *, const char *, ssize_t, int);
 extern int fifo_trigger(const char *, const char *, ssize_t, int);
 extern int stream_trigger(const char *, const char *, ssize_t, int);
-extern int unix_pass_trigger(const char *, const char *, ssize_t, int);
-
-#define stream_pass_trigger	stream_trigger
+extern int pass_trigger(const char *, const char *, ssize_t, int);
 
 /* LICENSE
 /* .ad
