@@ -166,10 +166,7 @@ VSTRING *escape(VSTRING *result, const char *data, ssize_t len)
 		continue;
 	    }
 	}
-	if (ISDIGIT(*UCHAR(data)))
-	    vstring_sprintf_append(result, "\\%03d", ch);
-	else
-	    vstring_sprintf_append(result, "\\%d", ch);
+	vstring_sprintf_append(result, "\\%03o", ch);
     }
     VSTRING_TERMINATE(result);
     return (result);
@@ -188,18 +185,20 @@ int     main(int argc, char **argv)
     VSTRING *out = vstring_alloc(10);
     int     un_escape = 1;
 
-    if (argc > 2 || (un_escape = strcmp(argv[1], "-e")) != 0)
+    if (argc > 2 || (argc > 1 && (un_escape = strcmp(argv[1], "-e"))) != 0)
 	msg_fatal("usage: %s [-e (escape)]", argv[0]);
 
     if (un_escape) {
 	while (vstring_fgets_nonl(in, VSTREAM_IN)) {
 	    unescape(out, vstring_str(in));
 	    vstream_fwrite(VSTREAM_OUT, vstring_str(out), VSTRING_LEN(out));
+	    VSTREAM_PUTC('\n', VSTREAM_OUT);
 	}
     } else {
-	while (vstring_fgets(in, VSTREAM_IN)) {
+	while (vstring_fgets_nonl(in, VSTREAM_IN)) {
 	    escape(out, vstring_str(in), VSTRING_LEN(in));
 	    vstream_fwrite(VSTREAM_OUT, vstring_str(out), VSTRING_LEN(out));
+	    VSTREAM_PUTC('\n', VSTREAM_OUT);
 	}
     }
     vstream_fflush(VSTREAM_OUT);
