@@ -67,6 +67,7 @@
 #include "mymalloc.h"
 #include "vbuf.h"
 #include "vstring.h"
+#include "stringops.h"
 #include "vbuf_print.h"
 
  /*
@@ -290,8 +291,7 @@ VBUF   *vbuf_print(VBUF *bp, const char *format, va_list ap)
 		break;
 	    case 'm':
 		/* Ignore the 'l' modifier, width and precision. */
-		VBUF_STRCAT(bp, saved_errno ?
-			    strerror(saved_errno) : "Application error");
+		VBUF_STRCAT(bp, mystrerror(saved_errno));
 		break;
 	    case 'p':
 		if (long_flag)
